@@ -191,6 +191,7 @@ describe WillPaginate::ActiveRecord do
     it "keeps :include for count when they are referenced in :conditions" do
       developers = Developer.paginate(:page => 1, :per_page => 1).includes(:projects)
       with_condition = developers.where('projects.id > 1')
+      with_condition = with_condition.references(:projects) if with_condition.respond_to?(:references)
       with_condition.total_entries.should == 1
 
       $query_sql.last.should =~ /\bJOIN\b/
@@ -199,6 +200,10 @@ describe WillPaginate::ActiveRecord do
     it "should count with group" do
       Developer.group(:salary).page(1).total_entries.should == 4
     end
+    
+    it "should count with select" do
+      Topic.select('title, content').page(1).total_entries.should == 4
+    end
 
     it "removes :reorder for count with group" do
       Project.group(:id).reorder(:id).page(1).total_entries
@@ -304,13 +309,16 @@ describe WillPaginate::ActiveRecord do
   end
 
   it "should paginate with :include and :conditions" do
-    result = Topic.paginate \
+    klass = Topic
+    klass = klass.references(:replies) if klass.respond_to?(:references)
+
+    result = klass.paginate \
       :page     => 1, 
       :include  => :replies,  
       :conditions => "replies.content LIKE 'Bird%' ", 
       :per_page => 10
 
-    expected = Topic.find :all, 
+    expected = klass.find :all,
       :include => 'replies', 
       :conditions => "replies.content LIKE 'Bird%' ", 
       :limit   => 10
@@ -339,13 +347,19 @@ describe WillPaginate::ActiveRecord do
     it "should paginate with include" do
       project = projects(:active_record)
 
-      result = project.topics.paginate \
+      topics = project.topics
+      topics = topics.references(:replies) if topics.respond_to?(:references)
+
+      result = topics.paginate \
         :page       => 1, 
         :include    => :replies,  
         :conditions => ["replies.content LIKE ?", 'Nice%'],
         :per_page   => 10
 
-      expected = Topic.find :all, 
+      topics = Topic
+      topics = topics.references(:replies) if topics.respond_to?(:references)
+
+      expected = topics.find :all,
         :include    => 'replies', 
         :conditions => ["project_id = ? AND replies.content LIKE ?", project.id, 'Nice%'],
         :limit      => 10
@@ -360,8 +374,10 @@ describe WillPaginate::ActiveRecord do
 
       lambda {
         # with association-specified order
-        result = ignore_deprecation { dhh.projects.paginate(:page => 1) }
-        result.should == expected_name_ordered
+        result = ignore_deprecation {
+          dhh.projects.includes(:topics).paginate(:page => 1, :order => 'projects.name')
+        }
+        result.to_a.should == expected_name_ordered
         result.total_entries.should == 2
       }.should run_queries(2)
 
