@@ -1,6 +1,7 @@
 require 'spec_helper'
 require 'active_support/rescuable' # needed for Ruby 1.9.1
 require 'action_controller'
+require 'action_view'
 require 'will_paginate/view_helpers/action_view'
 require 'will_paginate/collection'
 
@@ -312,13 +313,12 @@ describe WillPaginate::ActionView do
   end
 
   it "renders using ActionView helpers on a custom object" do
-    helper = Object.new
-    class << helper
+    helper = Class.new {
       attr_reader :controller
       include ActionView::Helpers::UrlHelper
       include Routes.url_helpers
       include WillPaginate::ActionView
-    end
+    }.new
     helper.default_url_options[:controller] = 'dummy'
 
     collection = WillPaginate::Collection.new(2, 1, 3)
@@ -331,12 +331,11 @@ describe WillPaginate::ActionView do
   end
 
   it "renders using ActionDispatch helper on a custom object" do
-    helper = Object.new
-    class << helper
+    helper = Class.new {
       include ActionDispatch::Routing::UrlFor
       include Routes.url_helpers
       include WillPaginate::ActionView
-    end
+    }.new
     helper.default_url_options.update \
       :only_path => true,
       :controller => 'dummy'
@@ -398,6 +397,7 @@ end
 
 class DummyRequest
   attr_accessor :symbolized_path_parameters
+  alias :path_parameters :symbolized_path_parameters
   
   def initialize
     @get = true
